VERB={
  "之,v,動詞,行為,移動":"ゆか:ゆき:ゆく:ゆく:ゆけ:ゆけ",
  "于,v,動詞,存在,存在":"xてせ:x:xてす:xてする:xてせ:xてせよ",
  "令,v,動詞,行為,使役":"しめ:しめ:しむ:しむる:しむれ:しめよ",
  "以,v,動詞,行為,動作":"xてせ:x:xてす:xてする:xてせ:xてせよ",
  "使,v,動詞,行為,使役":"しめ:しめ:しむ:しむる:しむれ:しめよ",
  "來,v,動詞,行為,移動":"x:x:xる:xる:xれ:xよ",
  "信,v,動詞,行為,態度":"xじ:xじ:xず:xじる:xじれ:xじよ",
  "利,v,動詞,行為,得失":"xさ:xし:xす:xす:xせ:xせ",
  "卒,v,動詞,変化,生物":"xさ:xし:xす:xす:xせ:xせ",
  "可,v,動詞,描写,態度":"xとせ:xとし:xとす:xとする:xとすれ:xとせよ",
  "同,v,動詞,描写,形質":"xじとせ:xじとし:xじ:xじ:xじとすれ:xじとせよ",
  "否,v,動詞,描写,態度":"xま:xみ:xむ:xむ:xめ:xめ",
  "在,v,動詞,存在,存在":"xら:xり:xり:xる:xれ:xれ",
  "失,v,動詞,行為,得失":"xは:xひ:xふ:xふ:xへ:xへ",
  "奈,v,動詞,行為,分類":"ごとくあら:ごとく:ごとし:ごとき:ごとくあれ:ごとくあれ",
  "如,v,動詞,行為,分類":"xくあら:xく:xし:xき:xくあれ:xくあれ",
  "妄,v,動詞,描写,態度":"xさ:xし:xす:xす:xせ:xせ",
  "安,v,動詞,行為,態度":"xんぜ:xんじ:xんず:xんずる:xんじれ:xんぜよ",
  "對,v,動詞,行為,伝達":"xへ:xへ:xふ:xへる:xへれ:xへよ",
  "屬,v,動詞,行為,設置":"xさ:xし:xす:xす:xせ:xせ",
  "忍,v,動詞,描写,態度":"xば:xび:xぶ:xぶ:xべ:xべ",
  "折,v,動詞,行為,動作":"xら:xり:xる:xる:xれ:xれ",
  "招,v,動詞,行為,動作":"xか:xき:xく:xく:xけ:xけ",
  "於,v,動詞,存在,存在":"xてせ:x:xてす:xてする:xてせ:xてせよ",
  "易,v,動詞,描写,形質":"xから:xく:xし:xき:xけれ:xくせよ",
  "易,v,動詞,行為,動作":"xへ:xへ:xへる:xへる:xへれ:xへよ",
  "曰,v,動詞,行為,伝達":"xは:xひ:xく:xふ:xへ:xへ",
  "有,v,動詞,存在,存在":"xら:xり:xり:xる:xれ:xれ",
  "樂,v,動詞,行為,態度":"xしま:xしみ:xし:xしむ:xしめ:xしめ",
  "欲,v,動詞,行為,動作":"xさ:xし:xす:xする:xせ:xせよ",
  "治,v,動詞,行為,動作":"xめ:xめ:xむ:xめる:xめれ:xめよ",
  "無,v,動詞,存在,存在":"xから:xく:xし:xき:xけれ:xかれ",
  "然,v,動詞,描写,態度":"xら:xり:xり:xる:xれ:xれ",
  "爲,v,動詞,存在,存在":"たら:たり:たり:たる:たれ:たれ",
  "爲,v,動詞,行為,生産":"xさ:xし:xす:xす:xせ:xせ",
  "猶,v,動詞,行為,分類":"ごとくあら:ごとく:ごとし:ごとき:ごとくあれ:ごとくあれ",
  "畏,v,動詞,行為,態度":"xれ:xれ:xれる:xれる:xれれ:xれよ",
  "異,v,動詞,描写,形質":"xなら:xなり:xなる:xなる:xなれ:xなれ",
  "盡,v,動詞,行為,動作":"xさ:xし:xす:xす:xせ:xせ",
  "笑,v,動詞,行為,態度":"xは:xひ:xふ:xふ:xへ:xへ",
  "聞,v,動詞,行為,伝達":"xか:xき:xく:xく:xけ:xけ",
  "至,v,動詞,行為,移動":"xら:xり:xる:xる:xれ:xれ",
  "興,v,動詞,行為,動作":"xさ:xし:xす:xす:xせ:xせ",
  "興,v,動詞,行為,態度":"xじ:xじ:xず:xじる:xじれ:xじよ",
  "若,v,動詞,行為,分類":"ごとくあら:ごとく:ごとし:ごとき:ごとくあれ:ごとくあれ",
  "行,v,動詞,行為,動作":"xは:xひ:xふ:xふ:xへ:xへ",
  "行,v,動詞,行為,移動":"xか:xき:xく:xく:xけ:xけ",
  "見,v,動詞,行為,動作":"x:x:xる:xる:xれ:xよ",
  "言,v,動詞,行為,伝達":"xは:xひ:xふ:xふ:xへ:xへ",
  "語,v,動詞,行為,伝達":"xら:xり:xる:xる:xれ:xれ",
  "說,v,動詞,行為,伝達":"xか:xき:xく:xく:xけ:xけ",
  "說,v,動詞,行為,態度":"xば:xび:xぶ:xぶ:xべ:xべ",
  "賢,v,動詞,描写,態度":"xから:xく:xし:xき:xけれ:xくせよ",
  "遣,v,動詞,行為,使役":"しめ:しめ:しむ:しむる:しむれ:しめよ",
  "重,v,動詞,描写,量":"xね:xね:xねる:xねる:xねれ:xねよ",
  "須,v,動詞,行為,動作":"xた:xち:xつ:xつ:xて:xて",
  "顧,v,動詞,行為,動作":"xみ:xみ:xみる:xみる:xみれ:xみよ",
} #:#
