ADV={
  "不,v,副詞,否定,無界":"ず:AUX",
  "且,v,副詞,時相,将来":"んとす:AUX",
  "乍,v,副詞,時相,緊接":"たちまち:ADV",
  "但,v,副詞,範囲,限定":"ただ:ADV",
  "何,v,副詞,疑問,原因":"何ぞ:ADV",
  "再,v,副詞,頻度,重複":"再び:ADV",
  "凡,v,動詞,描写,形質":"凡そ:ADV",
  "則,v,副詞,時相,緊接":"則ち:ADV",
  "勿,v,副詞,否定,禁止":"なし:AUX",
  "各,v,副詞,範囲,限定":"各々:ADV",
  "同,v,副詞,範囲,共同":"同じく:ADV",
  "同,v,動詞,描写,形質":"同じく:ADV",
  "善,v,動詞,描写,態度":"善く:ADV",
  "因,v,副詞,判断,確定":"因て:ADV",
  "固,v,副詞,判断,確定":"固く:ADV",
  "奚,v,副詞,疑問,原因":"なんぞ:ADV",
  "如,v,副詞,判断,推定":"もし:ADV",
  "始,v,動詞,行為,動作":"はじめ:ADV",
  "安,v,副詞,疑問,所在":"いずくんぞ:ADV",
  "將,v,副詞,時相,将来":"んとす:AUX",
  "幾,v,副詞,判断,推定":"幾ら:ADV",
  "弗,v,副詞,否定,無界":"ず:AUX",
  "惟,v,副詞,範囲,限定":"ただ:ADV",
  "惡,v,副詞,疑問,所在":"いずくんぞ:ADV",
  "或,v,副詞,判断,推定":"あるいは:ADV",
  "方,v,副詞,時相,現在":"まさに:ADV",
  "既,v,副詞,時相,完了":"すでに:ADV",
  "曩,v,副詞,時相,過去":"むかし:ADV",
  "曷,v,副詞,疑問,原因":"なんぞ:ADV",
  "未,v,副詞,否定,有界":"未だ:ADV",
  "殆,v,副詞,判断,推定":"ほとんど:ADV",
  "毋,v,副詞,否定,禁止":"なし:AUX",
  "焉,v,副詞,疑問,所在":"いずくんぞ:ADV",
  "皆,v,副詞,範囲,総括":"みな:ADV",
  "盍,v,副詞,疑問,原因":"なんぞ:ADV",
  "相,v,副詞,範囲,共同":"たがいに:ADV",
  "終,v,動詞,変化,生物":"つひに:ADV",
  "胡,v,副詞,疑問,原因":"なんぞ:ADV",
  "舉,v,副詞,範囲,総括":"舉げて:ADV",
  "苟,v,副詞,判断,推定":"いやしくも:ADV",
  "若,v,副詞,判断,推定":"もし:ADV",
  "莫,v,副詞,否定,禁止":"なし:AUX",
  "言,v,副詞,時相,緊接":"ここに:ADV",
  "誠,v,動詞,描写,態度":"誠に:ADV",
  "雖,v,副詞,判断,逆接":"雖も:ADV",
  "非,v,副詞,否定,体言否定":"非ず:AUX",
}
