PART={
  "之,n,代名詞,人称,止格":"これ:PRON",
  "乎,p,助詞,句末,*":"や:PART",
  "乎,p,接尾辞,*,*":"や:PART",
  "也,p,助詞,句末,*":"なり:AUX",
  "也,p,助詞,提示,*":"なる:PART",
  "兮,p,助詞,句末,*":"よ:PART",
  "已,p,助詞,句末,*":"のみ:PART",
  "攸,p,助詞,接続,体言化":"ところ:PART",
  "而,p,助詞,接続,並列":"而して:CCONJ",
  "耳,p,助詞,句末,*":"のみ:PART",
  "自,n,代名詞,人称,他":"自ら:PRON",
  "若,n,代名詞,人称,他":"なんじ:PRON",
  "蓋,p,助詞,句頭,*":"けだし:PART",
}
