AUX={
  "す,_":"せ:し:す:する:すれ:せよ",
  "ず,_":"ざら:ずし:ず:ざる:ざれ:ざれ",
  "なり,_":"なら:なり:なり:なる:なれ:なれ",
  "不,v,副詞,否定,無界":"ざら:ずし:ず:ざる:ざれ:ざれ",
  "且,v,副詞,時相,将来":"んとせ:んとし:んとす:んとする:んとすれ:んとせよ",
  "也,p,助詞,句末,*":"なら:なり:なり:なる:なれ:なれ",
  "也,p,助詞,提示,*":"なら:なり:なり:なる:なれ:なれ",
  "儀,v,助動詞,必要,*":"べから:べく:べし:べき:べけれ:べけれ",
  "勿,v,副詞,否定,禁止":"なから:なく:なかれ:なき:なけれ:なかれ",
  "可,v,助動詞,可能,*":"べから:べく:べし:べき:べけれ:べけれ",
  "宜,v,助動詞,必要,*":"べから:べく:べし:べき:べけれ:べけれ",
  "將,v,副詞,時相,将来":"んとせ:んとし:んとす:んとする:んとすれ:んとせよ",
  "弗,v,副詞,否定,無界":"ざら:ずし:ず:ざる:ざれ:ざれ",
  "得,v,助動詞,可能,*":"得:得:得る:得る:得れ:得よ",
  "敢,v,助動詞,願望,*":"敢へてせ:敢へ:敢へてす:敢へてする:敢へてすれ:敢へてせよ",
  "欲,v,助動詞,願望,*":"欲さ:欲し:欲す:欲する:欲せ:欲せよ",
  "毋,v,副詞,否定,禁止":"なから:なく:なかれ:なき:なけれ:なかれ",
  "肯,v,助動詞,願望,*":"肯へてせ:肯へ:肯へてす:肯へてする:肯へてすれ:肯へてせよ",
  "能,v,助動詞,可能,*":"能は:能ひ:能ふ:能ふる:能へ:能へよ",
  "莫,v,副詞,否定,禁止":"なから:なく:なかれ:なき:なけれ:なかれ",
  "被,v,助動詞,受動,*":"られ:られ:らる:らるる:られ:られよ",
  "見,v,助動詞,受動,*":"られ:られ:らる:らるる:られ:られよ",
  "足,v,助動詞,可能,*":"足ら:足り:足る:足る:足れ:足れ",
  "非,v,副詞,否定,体言否定":"非ざら:非ずし:非ず:非ざる:非ざれ:非ざれ",
  "須,v,助動詞,必要,*":"べから:べく:べし:べき:べけれ:べけれ",
}
